# Topsis-Sanat-101903326
It takes an integer as an input and prints it square.

## Installation
```pip install Topsis-Sanat-101903326```

## License

© 2022 Sanat Mahajan

This repository is licensed under the MIT license. See LICENSE for details.